@@ -16,7 +16,7 @@
  *  along with this program; if not, write to the Free Software
  *  Foundation, Inc., 59 Temple Street #330, Boston, MA 02111-1307, USA.
  *
- $Id: power-management.c,v 1.4 2005/01/14 04:06:40 ryanl Exp $
+ $Id: power-management.c,v 1.5 2005/02/24 08:54:02 kmaraas Exp $
  */
 
 #ifdef HAVE_CONFIG_H
@@ -164,10 +164,10 @@ apm_readinfo (BatteryStatus *status)
 #include "acpi-linux.h"
 
 struct acpi_info acpiinfo;
-gboolean using_acpi;
-int acpi_count;
-int acpiwatch;
-struct apm_info apminfo;
+static gboolean using_acpi;
+static int acpi_count;
+static int acpiwatch;
+static struct apm_info apminfo;
 
 /* Declared in acpi-linux.c */
 gboolean acpi_linux_read(struct apm_info *apminfo, struct acpi_info *acpiinfo);
