@@ -1,5 +1,6 @@
 /*
- * Copyright (C) 2001, 2002 Free Software Foundation
+ * GNOME CPUFreq Applet 
+ * Copyright (C) 2004 Carlos Garcia Campos <carlosgc@gnome.org>
  *
  *  This library is free software; you can redistribute it and/or
  *  modify it under the terms of the GNU General Public
@@ -213,7 +214,7 @@ cpufreq_applet_about_cb (BonoboUIComponent *uic, CPUFreqApplet *applet, const gc
 	   gtk_show_about_dialog (NULL,
 		"name",		_("CPU Frequency Scaling Monitor"),
 		"version",	VERSION,
-		"copyright",	"\xC2\xA9 2004 Free Software Foundation. Inc.",
+		"copyright",	"\xC2\xA9 2004 Carlos Garcia Campos",
 		"comments",	_("This utility shows the current CPU "
 				  "Frequency Scaling."),
 		"authors",	authors,
@@ -228,7 +229,7 @@ cpufreq_applet_about_cb (BonoboUIComponent *uic, CPUFreqApplet *applet, const gc
 }
 
 static gint
-cpufreq_applet_get_max_cpu ()
+cpufreq_applet_get_max_cpu (void)
 {
 	   gint   mcpu = -1;
 	   gchar *file = NULL;
@@ -655,7 +656,7 @@ cpufreq_applet_change_background (PanelApplet *pa,
 	   gtk_widget_set_style (GTK_WIDGET (applet), NULL);
 	   rc_style = gtk_rc_style_new ();
 	   gtk_widget_modify_style (GTK_WIDGET (applet), rc_style);
-	   g_object_unref (rc_style);
+	   gtk_rc_style_unref (rc_style);
 	   
 	   switch (type) {
 	   case PANEL_PIXMAP_BACKGROUND:
@@ -666,6 +667,7 @@ cpufreq_applet_change_background (PanelApplet *pa,
 			 style->bg_pixmap[GTK_STATE_NORMAL] = g_object_ref (
 					 pixmap);
 			 gtk_widget_set_style (GTK_WIDGET (applet), style);
+			 g_object_unref (style);
 			 break;
 	   case PANEL_COLOR_BACKGROUND:
 			 gtk_widget_modify_bg (GTK_WIDGET (applet),
