@@ -26,18 +26,18 @@
 
 #include <gconf/gconf-client.h>
 #include <panel-applet-gconf.h>
-#include <egg-screen-help.h>
+#include <libgnomeui/gnome-help.h>
 #include "geyes.h"
 
 #define NUM_THEME_DIRECTORIES 2
 #define HIG_IDENTATION  "    "
 
-gchar *theme_directories[NUM_THEME_DIRECTORIES];
+static char *theme_directories[NUM_THEME_DIRECTORIES];
 
 void
-theme_dirs_create ()
+theme_dirs_create (void)
 {
-	static themes_created = FALSE;
+	static gboolean themes_created = FALSE;
 	
 	if (themes_created == TRUE)
 		return;
@@ -230,7 +230,7 @@ phelp_cb (GtkDialog *dialog)
 {
 	GError *error = NULL;
 
-	egg_help_display_on_screen (
+	gnome_help_display_on_screen (
 		"geyes", "geyes-settings",
 		gtk_window_get_screen (GTK_WINDOW (dialog)),
 		&error);
