@@ -1,4 +1,4 @@
-/* $Id: gweather-pref.c,v 1.85 2004/11/29 03:48:21 davyd Exp $ */
+/* $Id: gweather-pref.c,v 1.87 2005/01/18 18:09:49 bdejean Exp $ */
 
 /*
  *  Papadimitriou Spiros <spapadim+@cs.cmu.edu>
@@ -36,6 +36,7 @@
 #include "gweather-pref.h"
 #include "gweather-applet.h"
 #include "gweather-xml.h"
+#include "gweather-dialog.h"
 
 #define NEVER_SENSITIVE		"never_sensitive"
 
@@ -202,8 +203,6 @@ static gint cmp_loc (const WeatherLocation *l1, const WeatherLocation *l2)
 /* Update pref dialog from gweather_pref */
 static gboolean update_dialog (GWeatherApplet *gw_applet)
 {
-    GtkCTreeNode *node;
-    
     g_return_val_if_fail(gw_applet->gweather_pref.location != NULL, FALSE);
 
     gtk_spin_button_set_value(GTK_SPIN_BUTTON(gw_applet->pref_basic_update_spin), 
@@ -778,7 +777,6 @@ static void gweather_pref_create (GWeatherApplet *gw_applet)
     GtkObject *pref_basic_update_spin_adj;
     GtkWidget *pref_basic_update_sec_lbl;
     GtkWidget *pref_basic_note_lbl;
-    GtkWidget *pref_net_note_lbl;    
     GtkWidget *pref_loc_hbox;
     GtkWidget *pref_loc_note_lbl;
     GtkWidget *scrolled_window;
@@ -840,7 +838,7 @@ static void gweather_pref_create (GWeatherApplet *gw_applet)
 	    hard_set_sensitive (gw_applet->pref_basic_update_btn, FALSE);
 
     /* Temperature Unit */
-    temp_label = gtk_label_new_with_mnemonic (_("_Temperature Unit:"));
+    temp_label = gtk_label_new_with_mnemonic (_("_Temperature unit:"));
     gtk_label_set_use_markup (GTK_LABEL (temp_label), TRUE);
     gtk_label_set_justify (GTK_LABEL (temp_label), GTK_JUSTIFY_LEFT);
     gtk_misc_set_alignment (GTK_MISC (temp_label), 0, 0.5);
@@ -860,7 +858,7 @@ static void gweather_pref_create (GWeatherApplet *gw_applet)
         hard_set_sensitive (gw_applet->pref_basic_temp_combo, FALSE);
 	
     /* Speed Unit */
-    speed_label = gtk_label_new_with_mnemonic (_("_Wind Speed Unit:"));
+    speed_label = gtk_label_new_with_mnemonic (_("_Wind speed unit:"));
     gtk_label_set_use_markup (GTK_LABEL (speed_label), TRUE);
     gtk_label_set_justify (GTK_LABEL (speed_label), GTK_JUSTIFY_LEFT);
     gtk_misc_set_alignment (GTK_MISC (speed_label), 0, 0.5);
@@ -884,7 +882,7 @@ static void gweather_pref_create (GWeatherApplet *gw_applet)
         hard_set_sensitive (gw_applet->pref_basic_speed_combo, FALSE);
 
     /* Pressure Unit */
-    pres_label = gtk_label_new_with_mnemonic (_("_Pressure Unit:"));
+    pres_label = gtk_label_new_with_mnemonic (_("_Pressure unit:"));
     gtk_label_set_use_markup (GTK_LABEL (pres_label), TRUE);
     gtk_label_set_justify (GTK_LABEL (pres_label), GTK_JUSTIFY_LEFT);
     gtk_misc_set_alignment (GTK_MISC (pres_label), 0, 0.5);
@@ -910,7 +908,7 @@ static void gweather_pref_create (GWeatherApplet *gw_applet)
         hard_set_sensitive (gw_applet->pref_basic_pres_combo, FALSE);
 
     /* Distance Unit */
-    dist_label = gtk_label_new_with_mnemonic (_("_Visibility Unit:"));
+    dist_label = gtk_label_new_with_mnemonic (_("_Visibility unit:"));
     gtk_label_set_use_markup (GTK_LABEL (dist_label), TRUE);
     gtk_label_set_justify (GTK_LABEL (dist_label), GTK_JUSTIFY_LEFT);
     gtk_misc_set_alignment (GTK_MISC (dist_label), 0, 0.5);
@@ -931,15 +929,24 @@ static void gweather_pref_create (GWeatherApplet *gw_applet)
     if ( ! key_writable (gw_applet->applet, GCONF_DISTANCE_UNIT))
         hard_set_sensitive (gw_applet->pref_basic_dist_combo, FALSE);
 	
-	unit_table = gtk_table_new(5, 3, FALSE);
+	unit_table = gtk_table_new(5, 2, FALSE);
 	gtk_table_set_row_spacings(GTK_TABLE(unit_table), 6);
-	gtk_table_attach_defaults(GTK_TABLE(unit_table), temp_label,  0, 1, 0, 1);
+	gtk_table_set_col_spacings(GTK_TABLE(unit_table), 12);
+	gtk_table_attach(GTK_TABLE(unit_table), temp_label, 0, 1, 0, 1,
+	                 (GtkAttachOptions) (GTK_FILL),
+	                 (GtkAttachOptions) (0), 0, 0);
 	gtk_table_attach_defaults(GTK_TABLE(unit_table), temp_combo,  1, 2, 0, 1);
-	gtk_table_attach_defaults(GTK_TABLE(unit_table), speed_label, 0, 1, 1, 2);
+	gtk_table_attach(GTK_TABLE(unit_table), speed_label, 0, 1, 1, 2,
+	                 (GtkAttachOptions) (GTK_FILL),
+	                 (GtkAttachOptions) (0), 0, 0);
 	gtk_table_attach_defaults(GTK_TABLE(unit_table), speed_combo, 1, 2, 1, 2);
-	gtk_table_attach_defaults(GTK_TABLE(unit_table), pres_label,  0, 1, 2, 3);
+	gtk_table_attach(GTK_TABLE(unit_table), pres_label, 0, 1, 2, 3,
+	                 (GtkAttachOptions) (GTK_FILL),
+	                 (GtkAttachOptions) (0), 0, 0);	
 	gtk_table_attach_defaults(GTK_TABLE(unit_table), pres_combo,  1, 2, 2, 3);
-	gtk_table_attach_defaults(GTK_TABLE(unit_table), dist_label,  0, 1, 3, 4);
+	gtk_table_attach(GTK_TABLE(unit_table), dist_label, 0, 1, 3, 4,
+	                 (GtkAttachOptions) (GTK_FILL),
+	                 (GtkAttachOptions) (0), 0, 0);	
 	gtk_table_attach_defaults(GTK_TABLE(unit_table), dist_combo,  1, 2, 3, 4);
 	gtk_widget_show(unit_table);
 	
@@ -1112,7 +1119,6 @@ void gweather_pref_load (GWeatherApplet *gw_applet)
 {
     GError *error = NULL;
 	gchar  *gconf_str = NULL;
-	gint   value = 0;
 	GWeatherPrefs *prefs = &(gw_applet->gweather_pref);
 
 	/* Assume we use unit defaults */
